----------------------------------------------------------------------------------
-- Company:        OHO-Elektronik
-- Engineer:       M.Randelzhofer
-- 
-- Create Date:    12.04.09 
-- Design Name: 
-- Module Name:    Demo2_Dy1 - Behavioral 
-- Project Name: 
-- Target Devices: 
-- Tool versions: 
-- Description: 
--
-- Dependencies: 
--
-- Revision: 
-- Revision 1.00 - File Created
-- Revision 1.01 - Brightness support
-- Revision 1.02 - Added display test
-- Revision 1.03 - display update support, new interface signal names

-- Additional Comments: 
-- Spartan S3E Starter Kit Demo of OHO_DY1 display module
----------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all ;
use work.OhoPack.all ;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM ;
--use UNISIM.VComponents.all ;

entity demo_dy1 is
Port (
  m50:                                                      in  std_logic ;
  sw_e,sw_n,sw_s,sw_w:                                      in  std_logic ;
  sw_ra,sw_rb,sw_rc:                                        in  std_logic ;
  slsw:                                                     in std_logic_vector(3 DOWNTO 0) ;
  j1_io1,j1_io2,j1_io3,j1_io4:                              inout  std_logic ;
  j2_io5,j2_io6,j2_io7,j2_io8:                              inout  std_logic ;
  j4_io9,j4_io10,j4_io11,j4_io12:                           inout  std_logic ;
  led:                                                      out std_logic_vector(7 DOWNTO 0)
) ;
end demo_dy1 ;


architecture Behavioral of demo_dy1 is

signal rst_n:                           std_logic ;
signal rclk,sclk,ser:                   std_logic ;
signal qh_l,qh_r:                       std_logic ;
signal dy_update:                       std_logic ;
signal dy_frameend:                     std_logic ;
signal dy_frameend_q:                   std_logic ;
signal dy_frameend_c:                   std_logic ;
signal dy_frame:                        std_logic ;
signal dp0,dp1,dp2,dp3:                 std_logic ;

signal dy_data:                         y2d_type ;
signal clkdiv:			                    std_logic_vector (31 downto 0) ;
signal dy_pwm:                          std_logic_vector(3 downto 0) ;


component Oho_Dy1
port (
  dy_clock:         in std_logic ;
  dy_rst_n:         in std_logic ;
  dy_data:          in y2d_type ;
  dy_update:        in std_logic ;
  dy_frame:         out std_logic ;
  dy_frameend:      out std_logic ;
  dy_frameend_c:    out std_logic ;
  dy_pwm:           in std_logic_vector(3 downto 0) ;
  dy_counter:       out std_logic_vector(31 downto 0) ;
  dy_sclk:          out std_logic ;
  dy_ser:           out std_logic ;
  dy_rclk:          out std_logic
) ;
end component ;


begin

rst_n <= not sw_s ;

DY1:Oho_Dy1 port map (
dy_clock => m50,
dy_rst_n => rst_n,
dy_data => dy_data,
dy_update  => dy_update,
dy_frame  => dy_frame,
dy_frameend  => dy_frameend,
dy_frameend_c  => dy_frameend_c,
dy_pwm => dy_pwm,
dy_counter => clkdiv,
dy_sclk => sclk,
dy_ser => ser,
dy_rclk => rclk
) ;

-- J4 @ S3E Starterkit - output for test signals
j4_io9 <= dy_frame ;
j4_io10 <= qh_l ;
j4_io11 <= qh_r ;
j4_io12 <= dy_frameend ;

-- define string with 15 digits respectively
dy_data(0) <= hex & dp0 & "000" & X"3" ;
dy_data(1) <= hex & dp1 & "000" & X"2" ;
dy_data(2) <= hex & dp2 & "000" & X"1" ;

dp0 <=     clkdiv(25) and     clkdiv(24) ;
dp1 <=     clkdiv(25) and not clkdiv(24) ;
dp2 <= not clkdiv(25) and     clkdiv(24) ;
dp3 <= not clkdiv(25) and not clkdiv(24) ;

dy_data(3) <= hex & dp3 & "000" & X"9" ;
dy_data(4) <= hex & dp3 & "000" & X"8" ;
dy_data(5) <= hex & dp3 & "000" & X"7" ;

dy_data(6) <= hex & sw_e & "000" & X"6" ;
dy_data(7) <= hex & sw_e & "000" & X"5" ;
dy_data(8) <= hex & sw_e & "000" & X"4" ;

dy_data(9) <= hex & sw_w & "000" & X"c" ;
dy_data(10) <= hex & sw_w & "000" & X"b" ;
dy_data(11) <= hex & sw_w & "000" & X"a" ;

dy_data(12) <= hex & dp3 & "000" & X"f" ;
dy_data(13) <= hex & dp3 & "000" & X"e" ;
dy_data(14) <= hex & dp3 & "000" & X"d" ;



-- swich off display update by pressing the nort switch
dy_update <= not sw_n ;

-- blink init led
led(3 downto 0) <= dp3 & dp2 & dp1& dp0 ;

-- show slide switches
led(7 downto 4) <= slsw ;
dy_pwm <= slsw ;

-- J1 @ S3E Starterkit - right display module
qh_r <= j1_io1 ; -- feed back '595 output from right display row,normally not used
j1_io2 <= qh_l and not sw_w ; -- display test
j1_io3 <= sclk ;
j1_io4 <= rclk ;

-- J2 @ S3E Starterkit - left display module
qh_l <= j2_io5 ; -- feed back '595 output from left display row to the right row
j2_io6 <= ser and not sw_e ; -- display test
j2_io7 <= sclk ;
j2_io8 <= rclk ;


end Behavioral;

